Class: Shadcn::Carousel::Preview
- Inherits:
-
ApplicationViewComponentPreview
- Object
- ViewComponentContrib::Preview::Base
- ApplicationViewComponentPreview
- Shadcn::Carousel::Preview
- Defined in:
- app/components/shadcn/carousel/preview.rb
Instance Method Summary collapse
- #default ⇒ Object
-
#sizes ⇒ Object
Upstream's "Sizes" and "Spacing": both are the caller's classes on the item, which is why neither is an argument.
-
#vertical ⇒ Object
Upstream's "Orientation".
Instance Method Details
#default ⇒ Object
6 7 8 |
# File 'app/components/shadcn/carousel/preview.rb', line 6 def default render_with_template end |
#sizes ⇒ Object
Upstream's "Sizes" and "Spacing": both are the caller's classes on the item, which is why neither is an argument.
12 13 14 |
# File 'app/components/shadcn/carousel/preview.rb', line 12 def sizes render_with_template end |
#vertical ⇒ Object
Upstream's "Orientation".
17 18 19 |
# File 'app/components/shadcn/carousel/preview.rb', line 17 def vertical render_with_template end |