Class: Shadcn::InputGroup::Preview
- Inherits:
-
ApplicationViewComponentPreview
- Object
- ViewComponentContrib::Preview::Base
- ApplicationViewComponentPreview
- Shadcn::InputGroup::Preview
- Defined in:
- app/components/shadcn/input_group/preview.rb
Instance Method Summary collapse
-
#addons ⇒ Object
Upstream's "Icon", "Kbd", "Dropdown" and "Spinner" — what an addon holds, where the default preview shows where an addon sits.
- #default ⇒ Object
Instance Method Details
#addons ⇒ Object
Upstream's "Icon", "Kbd", "Dropdown" and "Spinner" — what an addon holds, where the default preview shows where an addon sits.
12 13 14 |
# File 'app/components/shadcn/input_group/preview.rb', line 12 def addons render_with_template end |
#default ⇒ Object
6 7 8 |
# File 'app/components/shadcn/input_group/preview.rb', line 6 def default render_with_template end |