Class: Shadcn::InputOtp::Preview
- Inherits:
-
ApplicationViewComponentPreview
- Object
- ViewComponentContrib::Preview::Base
- ApplicationViewComponentPreview
- Shadcn::InputOtp::Preview
- Defined in:
- app/components/shadcn/input_otp/preview.rb
Instance Method Summary collapse
- #default ⇒ Object
-
#variations ⇒ Object
Upstream's "Pattern", "Separator" and "Disabled" — and the FormBuilder, since a code that is not submitted is a code for nothing.
Instance Method Details
#default ⇒ Object
6 7 8 |
# File 'app/components/shadcn/input_otp/preview.rb', line 6 def default render_with_template end |
#variations ⇒ Object
Upstream's "Pattern", "Separator" and "Disabled" — and the FormBuilder, since a code that is not submitted is a code for nothing.
12 13 14 |
# File 'app/components/shadcn/input_otp/preview.rb', line 12 def variations render_with_template end |