Class: Shadcn::Select::Preview
- Inherits:
-
ApplicationViewComponentPreview
- Object
- ViewComponentContrib::Preview::Base
- ApplicationViewComponentPreview
- Shadcn::Select::Preview
- Defined in:
- app/components/shadcn/select/preview.rb
Instance Method Summary collapse
- #default ⇒ Object
- #scrollable ⇒ Object
- #searchable ⇒ Object
-
#states ⇒ Object
Upstream's "Disabled" — as a disabled item, which is the half a listbox has to answer for — and "Invalid".
Instance Method Details
#default ⇒ Object
6 7 8 |
# File 'app/components/shadcn/select/preview.rb', line 6 def default render_with_template end |
#scrollable ⇒ Object
14 15 16 |
# File 'app/components/shadcn/select/preview.rb', line 14 def scrollable render_with_template end |
#searchable ⇒ Object
10 11 12 |
# File 'app/components/shadcn/select/preview.rb', line 10 def searchable render_with_template end |
#states ⇒ Object
Upstream's "Disabled" — as a disabled item, which is the half a listbox has to answer for — and "Invalid".
19 20 21 |
# File 'app/components/shadcn/select/preview.rb', line 19 def states render_with_template end |