Class: Shadcn::Toaster::Preview
- Inherits:
-
ApplicationViewComponentPreview
- Object
- ViewComponentContrib::Preview::Base
- ApplicationViewComponentPreview
- Shadcn::Toaster::Preview
- Defined in:
- app/components/shadcn/toaster/preview.rb
Instance Method Summary collapse
- #default ⇒ Object
-
#from_the_server ⇒ Object
Rendered with the page, which is what a Rails flash does.
Instance Method Details
#default ⇒ Object
6 7 8 |
# File 'app/components/shadcn/toaster/preview.rb', line 6 def default render_with_template end |
#from_the_server ⇒ Object
Rendered with the page, which is what a Rails flash does.
11 12 13 |
# File 'app/components/shadcn/toaster/preview.rb', line 11 def from_the_server render_with_template end |