Class: Shadcn::Tooltip::Preview
- Inherits:
-
ApplicationViewComponentPreview
- Object
- ViewComponentContrib::Preview::Base
- ApplicationViewComponentPreview
- Shadcn::Tooltip::Preview
- Defined in:
- app/components/shadcn/tooltip/preview.rb
Instance Method Summary collapse
- #default ⇒ Object
-
#sides ⇒ Object
Upstream's "Side": the same tooltip on each of the four edges.
-
#with_keyboard_shortcut ⇒ Object
Upstream's "With Keyboard Shortcut".
Instance Method Details
#default ⇒ Object
6 7 8 |
# File 'app/components/shadcn/tooltip/preview.rb', line 6 def default render_with_template end |
#sides ⇒ Object
Upstream's "Side": the same tooltip on each of the four edges.
11 12 13 |
# File 'app/components/shadcn/tooltip/preview.rb', line 11 def sides render_with_template end |
#with_keyboard_shortcut ⇒ Object
Upstream's "With Keyboard Shortcut".
16 17 18 |
# File 'app/components/shadcn/tooltip/preview.rb', line 16 def with_keyboard_shortcut render_with_template end |