Class: Shadcn::AlertDialog::Component
- Inherits:
-
Shadcn::ApplicationViewComponent
- Object
- ViewComponent::Base
- Shadcn::ApplicationViewComponent
- Shadcn::AlertDialog::Component
- Includes:
- Concerns::ModalRoot
- Defined in:
- app/components/shadcn/alert_dialog/component.rb
Overview
Port of registry/new-york-v4/ui/alert-dialog.tsx
Same primitive as Dialog, except Radix deliberately refuses to close an alert dialog on an outside click — the user has to pick an action.
Constant Summary
Constants inherited from Shadcn::ApplicationViewComponent
Shadcn::ApplicationViewComponent::CONTENTS_STYLE, Shadcn::ApplicationViewComponent::VOID_TAGS
Instance Attribute Summary
Attributes inherited from Shadcn::ApplicationViewComponent
Instance Method Summary collapse
Methods included from Concerns::ModalRoot
#call, #element_attributes, included, #initialize
Methods inherited from Shadcn::ApplicationViewComponent
#call, #css_classes, default_tag, #element_attributes, #initialize, #merged_style, #render_element, #shadcn_t, slot_name, #style_variants, #tag_name
Instance Method Details
#dismissable? ⇒ Boolean
17 |
# File 'app/components/shadcn/alert_dialog/component.rb', line 17 def dismissable? = false |